@@ -9,14 +9,17 @@ from lavender.views import registration, profile
 from lavender.views.api import packages, telemetry
 from lavender.views.nidhoggr import textures, users
 
-nidhoggr_urlpatterns = [
-    path('user/get', users.get),
-    path('user/check_password', users.check_password),
-    path('user/save', users.save),
+api_urlpatterns = [
+    path('user/get/', users.get),
+    path('user/check_password/', users.check_password),
+    path('user/save/', users.save),
 
-    path('texture/get', textures.get),
-    path('texture/upload', textures.upload),
-    path('texture/clear', textures.clear),
+    path('texture/get/', textures.get),
+    path('texture/upload/', textures.upload),
+    path('texture/clear/', textures.clear),
+
+    path('logs/upload/', telemetry.save_logs),
+    path('packages/list/', packages.package_list),
 ]
 
 
@@ -38,13 +41,7 @@ urlpatterns = [
     path('accounts/registration/', registration.registration, name='registration'),
     path('accounts/profile/', profile.profile, name='profile'),
 
-    path('api/v1/', include(nidhoggr_urlpatterns)),
-
-    path('api/v1/logs/upload/', telemetry.save_logs),
-    path('api/v1/packages/list/', packages.package_list),
-
-    # FIXME: Deprecated and will be removed soon
-    path('api/packages/', packages.package_list),
+    path('api/v1/', include(api_urlpatterns)),
 ]
 
 if settings.DEBUG:
